@@ -109,6 +109,25 @@ class StableDiffusionText2ImageGenerator:
 
                         with gr.Row():
                             with gr.Column():
+
+                                text2image_scheduler = gr.Dropdown(
+                                    choices=[
+                                        "DDIM",
+                                        "EulerA",
+                                        "Euler",
+                                        "LMS",
+                                        "Heun",
+                                    ],
+                                    value="DDIM",
+                                    label="Scheduler",
+                                )
+
+                                text2image_seed_generator = gr.Slider(
+                                    label="Seed(0 for random)",
+                                    minimum=0,
+                                    maximum=1000000,
+                                    value=0,
+                                )
                                 text2image_height = gr.Slider(
                                     minimum=128,
                                     maximum=1280,
@@ -124,24 +143,6 @@ class StableDiffusionText2ImageGenerator:
                                     value=512,
                                     label="Image Width",
                                 )
-                                text2image_scheduler = gr.Dropdown(
-                                    choices=[
-                                        "DDIM",
-                                        "EulerA",
-                                        "Euler",
-                                        "LMS",
-                                        "Heun",
-                                    ],
-                                    value="DDIM",
-                                    label="Scheduler",
-                                )
-
-                                text2image_seed_generator = gr.Number(
-                                    label="Seed(0 for random)",
-                                    min=0,
-                                    value=0,
-                                    max=1000000,
-                                )
 
                     text2image_predict = gr.Button(value="Generator")
 
@@ -150,7 +151,7 @@ class StableDiffusionText2ImageGenerator:
                         label="Generated images",
                         show_label=False,
                         elem_id="gallery",
-                    ).style(grid=(1, 2))
+                    ).style(grid=(1, 2), height=200)
 
             text2image_predict.click(
                 fn=StableDiffusionText2ImageGenerator().generate_image,
