@@ -4,6 +4,7 @@ from diffusers import (
     EulerDiscreteScheduler,
     HeunDiscreteScheduler,
     LMSDiscreteScheduler,
+    UniPCMultistepScheduler,
 )
 
 SCHEDULER_LIST = [
@@ -12,6 +13,7 @@ SCHEDULER_LIST = [
     "Euler",
     "LMS",
     "Heun",
+    "UniPC",
 ]
 
 
@@ -37,4 +39,9 @@ def get_scheduler_list(pipe, scheduler):
             pipe.scheduler.config
         )
 
+    elif scheduler == SCHEDULER_LIST[5]:
+        pipe.scheduler = UniPCMultistepScheduler.from_config(
+            pipe.scheduler.config
+        )
+
     return pipe
